'use strict';

var fetchres = require('fetchres');
var logger = require('ft-next-logger').logger;
var elasticAgent = require('./utils/elastic-agent');
var signedFetch = require('signed-aws-es-fetch');

module.exports = function(opts) {
	var uuid = [].concat(opts.uuid);
	var returnMany = Array.isArray(opts.uuid);
	var index = opts.index || 'v2_api_v2';

	if (uuid.length === 0) {
		return Promise.resolve([]);
	}

	return signedFetch(`https://next-elastic.ft.com/${index}/item/_mget`, {
			method: 'POST',
			body: JSON.stringify({ ids: uuid }),
			timeout: 3000,
			agent: elasticAgent
		})
		.then(function(response) {
			if (!response.ok) {
				logger.warn('Failed getting CAPIv2 content', {
					uuid: uuid,
					status: response.status
				});
			}
			return response;
		})
		.then(fetchres.json)
		.then(function(data) {
			var foundCount = 0;
			var docs = data.docs

				// Filter out any that haven't been found
				.filter(function(item) {
					if (item.found) {
						foundCount++;
						return true;
					}
				})
				.map(function(item) {
					return item._source;
				});
			if (returnMany) {
				return docs;
			}
			if (foundCount === 0) {
				throw new fetchres.BadServerResponseError(404);
			}
			return docs[0];
		});
};
