'use strict';

var fetchres = require('fetchres');
var logger = require('ft-next-logger').logger;
var signedFetch = require('signed-aws-es-fetch');
var elasticAgent = require('./utils/elastic-agent');

module.exports = function(opts) {
	var query = opts.query;
	var fields = opts.fields;
	var count = opts.count || 10;
	var offset = opts.offset || 0;
	var body;
	var queryObject;

	if (typeof query === 'object') {
		queryObject = query;
	} else {
		var convertedQuery = /^([a-zA-Z]+):"(.*)"$/.exec(query) || [];
		var taxonomy = convertedQuery[1].replace(/Id$/, '');
		var filter = 'item.metadata.' + taxonomy + '.term.' + (/Id$/.test(convertedQuery[1]) ? 'id' : 'name');
		var id = convertedQuery[2];
		var term = {};
		term[filter] = id;
		queryObject = {
			bool: {
				must: {
					term: term
				}
			}
		};

		if (!opts.includePodcasts) {
			queryObject.bool.must_not = {
				term: { 'item.metadata.sections.term.name': 'Podcasts' }
			};
		}
	}

	body = {
		fields: fields || [],
		from: offset,
		size: count,
		query: queryObject,
		sort: [
			{
				'item.lifecycle.lastPublishDateTime': {
					order: "desc"
				}
			}
		]
	};

	return signedFetch('https://next-elastic.ft.com/v1_api_v2/item/_search', {
			method: 'POST',
			body: JSON.stringify(body),
			timeout: 3000,
			agent: elasticAgent
		})
		.then(function(response) {
			if (!response.ok) {
				logger.warn('Failed getting SAPIv1 content from Elastic Search', {
					query: query,
					status: response.status
				});

			}
			return response;
		})
		.then(fetchres.json)
		.then(function(results) {
			var indexCount = results.hits.total;
			results = results.hits.hits.map(function(hit) {
				return fields ? hit : hit._id;
			});
			results.indexCount = indexCount;
			return results;
		});
};
