'use strict';

const fetchres = require('fetchres');
const logger = require('ft-next-logger').logger;
const signedFetch = require('signed-aws-es-fetch');
const elasticAgent = require('./utils/elastic-agent');

module.exports = function search(opts) {
	let filterObject;

	if (Array.isArray(opts.filter)) {
		let term = Object.defineProperty({}, opts.filter[0], {
			value: opts.filter[1],
			enumerable: true
		});

		filterObject = {
			bool: {
				must: {
					term: term
				}
			}
		};
	} else {
		filterObject = opts.filter;
	}

	let body = {
		// source filtering maintains consistent behaviour, loading stored
		// fields would require an additional normalisation step.
		_source: opts.fields || true,
		from: opts.offset || 0,
		size: opts.count || 10,
		filter: filterObject,
		sort: {
			publishedDate: { order: 'desc' }
		}
	};

	return signedFetch('https://next-elastic.ft.com/v3_api_v2/item/_search', {
			body: JSON.stringify(body),
			agent: elasticAgent,
			method: 'POST',
			timeout: 3000
		})
		.then(response => {
			if (!response.ok) {
				logger.warn('Failed getting content from Elastic Search', {
					query: JSON.stringify(opts.filter),
					status: response.status
				});
			}

			return fetchres.json(response);
		})
		.then(results => {
			let total = results.hits.total;

			results = results.hits.hits.map(hit => hit._source);
			results.total = total;

			return results;
		});
};
