/*global describe, beforeEach, it*/

'use strict';

GLOBAL.fetch = require('node-fetch');

const nock = require('nock');
const expect = require('chai').expect;
const subject = require('../src/search');

const fixtureFound = require('./fixtures/es-v3-search-found');
const fixtureEmpty = require('./fixtures/es-v3-search-empty');

describe('Search', () => {

	describe('results found', () => {

		let result;
		let request;

		beforeEach(() => {
			request = nock('https://next-elastic.ft.com')
				.post('/v3_api_v2/item/_search', /"field\.name":"found"/)
				.reply(200, fixtureFound);

			return subject({ filter: [ 'field.name', 'found' ] }).then(data => result = data);
		});

		it('posts search request', () => {
			expect(request.isDone()).to.be.ok;
		});

		it('returns an array of source documents', () => {
			expect(result).to.be.an.instanceof(Array);

			result.forEach(item => {
				expect(item).not.to.include.keys('_id', '_source');
			});
		});

		it('appends total search result count', () => {
			expect(result.total).to.equal(fixtureFound.hits.total);
		});

	});

	describe('results empty', () => {

		let result;
		let request;

		beforeEach(() => {
			request = nock('https://next-elastic.ft.com')
				.post('/v3_api_v2/item/_search', /"field\.name":"empty"/)
				.reply(200, fixtureEmpty);

			return subject({ filter: [ 'field.name', 'empty' ] }).then(data => result = data);
		});

		it('posts search request', () => {
			expect(request.isDone()).to.be.ok;
		});

		it('returns an empty array', () => {
			expect(result).to.be.an.instanceof(Array);
		});

		it('appends total search result count', () => {
			expect(result.total).to.equal(fixtureEmpty.hits.total);
		});

	});

});
